Gammapy examples folder
=======================

This folder contains the following:

* Python scripts that could be used as example scripts tutorials in the documentation.
* Python scripts needed by the sphinx-gallery extension to produce collections of examples use cases.

Only the Python scripts declared in the ``scripts.yaml`` file were downloaded by the
``gammapy download scripts`` command. This list was versioned for each release of Gammapy
as it was also the case for the Jupyter notebooks tutorials.

The Python scripts needed by sphinx-gallery extension are placed in folders declared in
the ``sphinx_gallery_conf`` variable in ``docs/conf.py`` script.
